Ashyq
==========


**ashyq** is a simple and (a-)synchronous framework for Private Ashyq API written in Python 3.7 with `requests <https://github.com/psf/requests>`_ and `aiohttp <https://github.com/aio-libs/aiohttp>`_. It helps you to get your status in Ashyq faster and simpler.

Official ashyq resources:
--------------------------
- News and community: [@ashyqpy](https://t.me/ashyqpy)
- Russian community: [@ashyqpy](https://t.me/ashyqpy)
- PyPI: [ashyq](https://pypi.python.org/pypi/ashyq)
- Source: [Github repo](https://github.com/arynyklas/ashyq)
- Issues/Bug tracker: [Github issues tracker](https://github.com/arynyklas/ashyq/issues)
